# deep.piste

Tools for implementing Deep.piste study

## Installation
pip install deep-piste

On windows you may need to install "Visual C++ Redistributable Packages for Visual Studio 2013" Microsoft C++ Build Tools: https://www.microsoft.com/en-us/download/details.aspx?id=40784 



